@@ -10,7 +10,8 @@ import numpy as np
 import numpyro
 import pandas as pd
 from logger_tt import logger
-from tqdm import tqdm
+from tqdm.rich import tqdm
+from tqdm.std import TqdmExperimentalWarning
 
 from metaDMG.errors import BadDataError, FittingError
 from metaDMG.fit import bayesian, fit_utils, frequentist
@@ -18,12 +19,21 @@ from metaDMG.fit.mismatches import add_reference_count
 from metaDMG.utils import Config
 
 
+# from tqdm import tqdm
+
 numpyro.enable_x64()
 
 #%%
 
 BAYESIAN_MAXIMUM_SIZE = 100
 
+#%%
+
+# XXX Works, but should be a better way
+# with warnings.catch_warnings():
+warnings.filterwarnings("ignore", category=TqdmExperimentalWarning)
+
+
 #%%
 
 
@@ -135,30 +145,13 @@ def add_count_information(fit_result, config, group, data):
 #%%
 
 
-# def timer_fit_MAP(config, data):
-#     # data = group_to_numpyro_data(config, group)
-#     # %timeit timer_fit_MAP(config, data)
-#     fit_result = {}
-#     with warnings.catch_warnings():
-#         warnings.filterwarnings("ignore")
-#         fit_all, fit_forward, fit_reverse = frequentist.make_fits(fit_result, data)
-
-
-# def timer_fit_bayesian(config, data, mcmc_PMD, mcmc_null):
-#     # data = group_to_numpyro_data(config, group)
-#     # %timeit timer_fit_bayesian(config, data, mcmc_PMD, mcmc_null)
-#     fit_result = {}
-#     bayesian.make_fits(fit_result, data, mcmc_PMD, mcmc_null)
-
-
 #%%
 
 
 def fit_single_group(
     config,
     group,
-    mcmc_PMD=None,
-    mcmc_null=None,
+    mcmm=None,
 ):
 
     fit_result = {}
@@ -177,6 +170,21 @@ def fit_single_group(
         logger.warning(s)
         return None
 
+    if mcmm is not None:
+        try:
+            bayesian.make_fits(
+                fit_result,
+                data,
+                mcmm,
+            )
+        except:
+            from metaDMG.fit.serial import _setup_logger
+
+            _setup_logger(config)
+            s = f"Error in bayesian.make_fits for tax_id {tax_id}, sample = {sample}."
+            s += "Skipping the Bayesian fit."
+            logger.warning(s)
+
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore")
 
@@ -186,28 +194,17 @@ def fit_single_group(
             data,
             sample,
             tax_id,
-        )  # fit_all, fit_forward, fit_reverse
+        )  # fit
 
     add_count_information(fit_result, config, group, data)
 
-    if mcmc_PMD is not None and mcmc_null is not None:
-        try:
-            bayesian.make_fits(fit_result, data, mcmc_PMD, mcmc_null)
-        except:
-            from metaDMG.fit.serial import _setup_logger
-
-            _setup_logger(config)
-            s = f"Error in bayesian.make_fits for tax_id {tax_id}, sample = {sample}."
-            s += "Skipping the Bayesian fit."
-            logger.warning(s)
-
     return fit_result
 
 
 def compute_fits_seriel(config, df_mismatches, with_progressbar=False):
 
     # Do not initialise MCMC if config["bayesian"] is False
-    mcmc_PMD, mcmc_null = bayesian.init_mcmcs(config)
+    mcmm = bayesian.init_mcmc(config)
 
     groupby = get_groupby(df_mismatches)
 
@@ -224,8 +221,8 @@ def compute_fits_seriel(config, df_mismatches, with_progressbar=False):
         res = fit_single_group(
             config,
             group,
-            mcmc_PMD,
-            mcmc_null,
+            mcmm,
+            # mcmc_null,
         )
 
         if res is not None:
@@ -648,6 +645,7 @@ def compute(config, df_mismatches):
 
     df_fit_results = pd.merge(df_fit_results, df_stat_cut, on="tax_id")
 
+    prefix = "" if config["bayesian"] else "MAP_"
     cols_ordered = [
         "sample",
         "tax_id",
@@ -655,8 +653,8 @@ def compute(config, df_mismatches):
         "tax_rank",
         "N_reads",
         "N_alignments",
-        "D_max",
-        "significance",
+        f"{prefix}damage",
+        f"{prefix}significance",
         "mean_L",
         "std_L",
         "mean_GC",
