@@ -62,7 +62,7 @@ def get_navbar():
             dcc.Download(id="export_pdf"),
         ],
         brand="metaDMG",
-        brand_href="https://github.com/metaDMG/metaDMG",
+        brand_href="https://github.com/metaDMG-dev/metaDMG-core",
         color="dark",
         dark=True,
         fluid=True,
@@ -81,13 +81,13 @@ def get_content_main(viz_results, start_configuration):
     dropdown_x_axis = dcc.Dropdown(
         id="xaxis_column",
         options=[{"label": i, "value": i} for i in columns],
-        value="Bayesian_significance" if viz_results.Bayesian else "significance",
+        value="significance" if viz_results.Bayesian else "MAP_significance",
     )
 
     dropdown_y_axis = dcc.Dropdown(
         id="yaxis_column",
         options=[{"label": i, "value": i} for i in columns],
-        value="Bayesian_D_max" if viz_results.Bayesian else "D_max",
+        value="damage" if viz_results.Bayesian else "MAP_damage",
     )
 
     XY_axis_dropdowns = [
@@ -343,7 +343,7 @@ def get_sidebar_left(viz_results, start_configuration):
         min_value=np.log10(10),
     )
 
-    slider_phi_column = "Bayesian_phi" if viz_results.Bayesian else "phi"
+    slider_phi_column = "phi" if viz_results.Bayesian else "MAP_phi"
     slider_phi = make_new_slider(
         viz_results,
         column=slider_phi_column,
@@ -484,45 +484,45 @@ def get_sidebar_right(start_configuration):
         ]
     )
 
-    sidebar_right_collapsed_toggle_forward_reverse_graph = dbc.Form(
-        [
-            dcc.Graph(
-                figure=figures.create_empty_figure(),
-                id="sidebar_right_graph_forward",
-                style={"height": "20vh"},
-                **viz_utils.get_graph_kwargs_no_buttons(),
-            ),
-            dcc.Graph(
-                figure=figures.create_empty_figure(),
-                id="sidebar_right_graph_reverse",
-                style={"height": "20vh"},
-                **viz_utils.get_graph_kwargs_no_buttons(),
-            ),
-        ]
-    )
+    # sidebar_right_collapsed_toggle_forward_only_graph = dbc.Form(
+    #     [
+    #         dcc.Graph(
+    #             figure=figures.create_empty_figure(),
+    #             id="sidebar_right_graph_forward",
+    #             style={"height": "20vh"},
+    #             **viz_utils.get_graph_kwargs_no_buttons(),
+    #         ),
+    #         # dcc.Graph(
+    #         #     figure=figures.create_empty_figure(),
+    #         #     id="sidebar_right_graph_reverse",
+    #         #     style={"height": "20vh"},
+    #         #     **viz_utils.get_graph_kwargs_no_buttons(),
+    #         # ),
+    #     ]
+    # )
 
-    sidebar_right_collapsed_toggle_forward_reverse = html.Div(
-        [
-            html.Div(
-                dbc.Button(
-                    "Forward / Reverse",
-                    id="sidebar_right_btn_toggle_forward_reverse",
-                    color="secondary",
-                    outline=True,
-                    size="lg",
-                ),
-                className="d-grid gap-2",
-            ),
-            dbc.Collapse(
-                sidebar_right_collapsed_toggle_forward_reverse_graph,
-                id="sidebar_right_collapsed_toggle_forward_reverse",
-                is_open=False,
-            ),
-            html.Br(),
-            html.Br(),
-            html.Br(),
-        ]
-    )
+    # sidebar_right_collapsed_toggle_forward_only = html.Div(
+    #     [
+    #         html.Div(
+    #             dbc.Button(
+    #                 "Forward / Reverse",
+    #                 id="sidebar_right_btn_toggle_forward_only",
+    #                 color="secondary",
+    #                 outline=True,
+    #                 size="lg",
+    #             ),
+    #             className="d-grid gap-2",
+    #         ),
+    #         dbc.Collapse(
+    #             sidebar_right_collapsed_toggle_forward_only_graph,
+    #             id="sidebar_right_collapsed_toggle_forward_only",
+    #             is_open=False,
+    #         ),
+    #         html.Br(),
+    #         html.Br(),
+    #         html.Br(),
+    #     ]
+    # )
 
     sidebar_right = html.Div(
         [
@@ -531,8 +531,8 @@ def get_sidebar_right(start_configuration):
             sidebar_right_collapsed_toggle_combined,
             html.Hr(),
             sidebar_right_results,
-            html.Hr(),
-            sidebar_right_collapsed_toggle_forward_reverse,
+            # html.Hr(),
+            # sidebar_right_collapsed_toggle_forward_only,
         ],
         id="sidebar_right",
         style=start_configuration.style_sidebar_right,
