@@ -4,6 +4,7 @@
 #%%
 
 import matplotlib.pyplot as plt
+import matplotlib.ticker as mtick
 import numpy as np
 import plotly.express as px
 import plotly.graph_objects as go
@@ -11,11 +12,14 @@ from dash.exceptions import PreventUpdate
 from matplotlib import ticker
 from matplotlib.backends.backend_pdf import PdfPages
 from matplotlib.ticker import EngFormatter
-from tqdm import tqdm
+from tqdm.rich import tqdm
 
 from metaDMG.viz import viz_utils
 
 
+# from tqdm import tqdm
+
+
 #%%
 
 plt.rcParams["text.usetex"] = True
@@ -86,7 +90,7 @@ def make_figure(
     viz_results,
     df=None,
     xaxis_column_name="significance",
-    yaxis_column_name="D_max",
+    yaxis_column_name="damage",
     d_columns_latex=None,
 ):
 
@@ -155,13 +159,22 @@ def make_figure(
     fig.update_xaxes(title=d_columns_latex[xaxis_column_name])
     fig.update_yaxes(title=d_columns_latex[yaxis_column_name])
 
+    if yaxis_column_name == "damage" or yaxis_column_name == "MAP_damage":
+        fig.update_yaxes(tickformat=".1%")
+
     return fig
 
 
 #%%
 
 
-def plot_group(viz_results, group, D_max_info=None, fit=None, forward_reverse=""):
+def plot_group(
+    viz_results,
+    group,
+    D_info=None,
+    fit=None,
+    forward_only=False,
+):
 
     custom_data_columns = [
         "direction",
@@ -198,6 +211,7 @@ def plot_group(viz_results, group, D_max_info=None, fit=None, forward_reverse=""
     fig.update_yaxes(
         title=r"",
         rangemode="nonnegative",  # tozero, nonnegative
+        tickformat=".1%",
     )
 
     fig.update_traces(hovertemplate=hovertemplate, marker={"size": 10})
@@ -211,7 +225,7 @@ def plot_group(viz_results, group, D_max_info=None, fit=None, forward_reverse=""
         hoverlabel_font_size=14,
     )
 
-    if forward_reverse == "":
+    if not forward_only:
         fig.update_layout(
             **layout,
             legend=dict(
@@ -241,28 +255,30 @@ def plot_group(viz_results, group, D_max_info=None, fit=None, forward_reverse=""
             font_size=30,
         )
 
-        # add D-max as single errorbar
-        if D_max_info is not None:
+        # add damage as single errorbar
+        if D_info is not None:
 
-            D_max, D_max_low, D_max_high = D_max_info
+            # D, D_low, D_high = D_info
+            D, D_std = D_info
 
             # fit with errorbars
             fig.add_trace(
                 go.Scatter(
                     x=[0.5],
-                    y=[D_max],
+                    y=[D],
                     error_y=dict(
                         type="data",
-                        symmetric=False,
-                        array=[D_max_high - D_max],
-                        arrayminus=[D_max - D_max_low],
+                        array=[D_std],
+                        # symmetric=False,
+                        # array=[D_high - D],
+                        # arrayminus=[D - D_low],
                         visible=True,
                         color="black",
                     ),
                     mode="markers",
-                    name="D-max",
+                    name="Damage",
                     marker_color="black",
-                    # hovertemplate=viz_results.hovertemplate_D_max,
+                    # hovertemplate=viz_results.hovertemplate_D,
                     hoverinfo="skip",
                 )
             )
@@ -341,7 +357,7 @@ def plot_group(viz_results, group, D_max_info=None, fit=None, forward_reverse=""
 #%%
 
 
-def update_raw_count_plots(viz_results, click_data, forward_reverse):
+def update_raw_count_plots(viz_results, click_data, forward_only):
     if click_data is not None:
 
         sample, tax_id = viz_utils.get_sample_tax_id_from_click_data(
@@ -352,22 +368,22 @@ def update_raw_count_plots(viz_results, click_data, forward_reverse):
         group = viz_results.get_single_count_group(
             sample,
             tax_id,
-            forward_reverse,
+            forward_only,
         )
         fit = viz_results.get_single_fit_prediction(
             sample,
             tax_id,
-            forward_reverse,
+            forward_only,
         )
 
-        D_max_info = viz_results.get_D_max(sample, tax_id)
+        D_info = viz_results.get_D(sample, tax_id)
 
         fig = plot_group(
             viz_results,
             group,
-            D_max_info,
+            D_info,
             fit,
-            forward_reverse,
+            forward_only,
         )
         return fig
     else:
@@ -391,8 +407,8 @@ def compute_markersize(
 
 def plt_scatterplot(df, viz_results):
 
-    x = "Bayesian_significance" if viz_results.Bayesian else "significance"
-    y = "Bayesian_D_max" if viz_results.Bayesian else "D_max"
+    x = "significance" if viz_results.Bayesian else "MAP_significance"
+    y = "damage" if viz_results.Bayesian else "MAP_damage"
 
     size_max = df["size"].max()
     size_min = df["size"].min()
@@ -419,12 +435,13 @@ def plt_scatterplot(df, viz_results):
                 label=r"$\verb|" + sample + r"|$" if viz_utils.has_latex() else sample,
             )
 
+        ax.yaxis.set_major_formatter(mtick.PercentFormatter(1.0))
         ax.set_xlabel(
-            r"$z$" if viz_results.Bayesian else r"$\lambda_\mathrm{LR}$",
+            r"Significance" if viz_results.Bayesian else r"Significance (MAP)",
             fontsize=12,
         )
         ax.set_ylabel(
-            r"$D_\mathrm{max}$",
+            r"Damage" if viz_results.Bayesian else r"Damage (MAP)",
             fontsize=12,
             labelpad=5,
         )
@@ -612,6 +629,7 @@ def plt_errorplot(viz_results, group, fit=None):
         ax.set_title(title, pad=30)
 
         ax.xaxis.set_major_locator(MultipleOffsetLocator(base=2, offset=1))
+        ax.yaxis.set_major_formatter(mtick.PercentFormatter(1.0))
 
         legend = ax.legend(
             # title=r"Direction:",
