@@ -37,13 +37,7 @@ def sort_dataframe(df):
     return df
 
 
-def clip_df(df, column):
-    if column in df.columns:
-        df["_" + column] = df[column]  # save original data _column
-        df[column] = np.clip(df[column], a_min=0, a_max=None)
-
-
-def pd_wide_to_long_forward_reverse(group_wide, sep, direction):
+def pd_wide_to_long_forward_only(group_wide, sep, direction):
     stub_names = ["k", "N", "f"]
     group_long = pd.wide_to_long(
         group_wide,
@@ -58,21 +52,20 @@ def pd_wide_to_long_forward_reverse(group_wide, sep, direction):
 
 def wide_to_long_df(group_wide):
 
-    group_long_forward = pd_wide_to_long_forward_reverse(
+    group_long_forward = pd_wide_to_long_forward_only(
         group_wide,
         sep="+",
         direction="Forward",
     )
 
     try:
-        group_long_reverse = pd_wide_to_long_forward_reverse(
+        group_long_reverse = pd_wide_to_long_forward_only(
             group_wide,
             sep="-",
             direction="Reverse",
         )
 
         group_long = pd.concat([group_long_forward, group_long_reverse])
-        # group_long.loc[:, ["k", "N"]] = group_long.loc[:, ["k", "N"]].astype(int)
 
     # happens when forward only
     except ValueError:
@@ -83,11 +76,6 @@ def wide_to_long_df(group_wide):
     return group_long
 
 
-# def remove_LCA_columns(columns):
-#     remove_cols = ["tax_name", "tax_rank", "N_alignments"]
-#     return [col for col in columns if col not in remove_cols]
-
-
 def correct_for_non_LCA(df):
     if "N_alignments" in df.columns:
         df["N_alignments"] = df["N_alignments"].fillna(np.nan)
@@ -115,34 +103,16 @@ def correct_for_non_LCA(df):
 #%%
 
 
-def compute_variance_scaling(df, phi_string):
-    phi = df[phi_string]
-    if "N_x=1_reverse" in df.columns:
-        N_x = [df["N_x=1_forward"], df["N_x=1_reverse"]]
-    else:
-        N_x = [df["N_x=1_forward"]]
-    N = np.mean(N_x)
-    return (phi + N) / (phi + 1)
-
-
-#%%
-
-
 def add_MAP_measures(df):
-    df["rho_Ac_abs"] = np.abs(df["rho_Ac"])
-    df["D_max_CI_low"] = df["D_max"] - df["D_max_std"]
-    df["D_max_CI_high"] = df["D_max"] + df["D_max_std"]
+    df["MAP_rho_Ac_abs"] = np.abs(df["MAP_rho_Ac"])
+    # df["MAP_damage_CI_low"] = df["MAP_damage"] - df["MAP_damage_std"]
+    # df["MAP_damage_CI_high"] = df["MAP_damage"] + df["MAP_damage_std"]
 
 
 def add_bayesian_measures(df):
-    df["Bayesian_significance"] = df["Bayesian_D_max"] / df["Bayesian_D_max_std"]
-    df["Bayesian_rho_Ac_abs"] = np.abs(df["Bayesian_rho_Ac"])
-
-    df["Bayesian_D_max_CI_low"] = df["Bayesian_D_max_confidence_interval_1_sigma_low"]
-    df["Bayesian_D_max_CI_high"] = df["Bayesian_D_max_confidence_interval_1_sigma_high"]
-
-    df["Bayesian_prob_not_zero_damage"] = 1 - df["Bayesian_prob_zero_damage"]
-    df["Bayesian_prob_gt_1p_damage"] = 1 - df["Bayesian_prob_lt_1p_damage"]
+    df["rho_Ac_abs"] = np.abs(df["rho_Ac"])
+    # df["damage_CI_low"] = df["damage_CI_1_sigma_low"]
+    # df["damage_CI_high"] = df["damage_CI_1_sigma_high"]
 
 
 #%%
@@ -173,26 +143,27 @@ class VizResults:
 
         add_MAP_measures(df)
 
-        if any(["Bayesian" in column for column in df.columns]) and (
-            not any(df["Bayesian_D_max"].isna())
-        ):
+        if "damage" in df.columns and (not any(df["damage"].isna())):
             self.Bayesian = True
             add_bayesian_measures(df)
+        else:
+            self.Bayesian = False
 
         log_columns = [
             "N_reads",
             "N_alignments",
-            # "lambda_LR",
-            "phi",
+            "MAP_phi",
             "k_sum_total",
             "N_sum_total",
         ]
+        if self.Bayesian:
+            log_columns.append("phi")
 
         for column in log_columns:
             log_column = "log_" + column
             df.loc[:, log_column] = np.log10(1 + df[column])
 
-        if np.isnan(df["asymmetry"]).any():
+        if "k-1" not in df.columns or np.isnan(df["k-1"]).any():
             self.contains_forward_only = True
             if "k-1" in df.columns:
                 df["forward_only"] = df["k-1"].isna()
@@ -289,19 +260,25 @@ class VizResults:
         return self.df.loc[mask]
 
     def _set_cmap(self):
-        # https://plotly.com/python/discrete-color/#color-sequences-in-plotly-express
-        # blue, orange, green, red, purple, brown, pink, grey, camouflage, turquoise
-        # cmap = px.colors.qualitative.D3
-        # cmap taken from http://www.cookbook-r.com/Graphs/Colors_%28ggplot2%29/
+        # cmap = [
+        #     "#0072B2",
+        #     "#D55E00",
+        #     "#009E73",
+        #     "#CC79A7",
+        #     "#E69F00",
+        #     "#56B4E9",
+        #     "#F0E442",
+        # ]
         cmap = [
-            "#0072B2",
-            "#D55E00",
-            "#009E73",
-            "#CC79A7",
-            "#E69F00",
-            "#56B4E9",
-            "#F0E442",
+            "#3BA0E7",
+            "#E7554C",
+            "#00B050",
+            "#b36fb5",
+            "#c0c0c0",
+            "#FFC000",
+            "#9f99c8",
         ]
+
         N_cmap = len(cmap)
 
         groupby = self.df.groupby("sample", sort=False)
@@ -309,7 +286,7 @@ class VizResults:
         symbol_counter = 0
         d_cmap = {}
         d_symbols = {}
-        markers = ["o", "s", "^", "v", "<", ">", "d"]
+        markers = ["o", "s", "^", "v", "<", ">", "damage"]
         d_markers = {}
         for i, (name, _) in enumerate(groupby):
 
@@ -325,7 +302,11 @@ class VizResults:
         self.d_symbols = d_symbols
         self.d_markers = d_markers
 
-        self.d_cmap_fit = {"Forward": cmap[0], "Reverse": cmap[3], "Fit": cmap[2]}
+        self.d_cmap_fit = {
+            "Forward": cmap[0],
+            "Reverse": cmap[1],
+            "Fit": cmap[2],
+        }
 
     def _set_hover_info(self):
 
@@ -338,15 +319,14 @@ class VizResults:
             "tax_id",
             # Bayesian Fits
             # Frequentist fits
-            "D_max",
-            "D_max_std",
-            "significance",
-            "q",
-            "q_std",
-            "phi",
-            "phi_std",
-            "rho_Ac",
-            "asymmetry",
+            "MAP_damage",
+            "MAP_damage_std",
+            "MAP_significance",
+            "MAP_q",
+            "MAP_q_std",
+            "MAP_phi",
+            "MAP_phi_std",
+            "MAP_rho_Ac",
             # Counts
             "N_reads",
             "N_alignments",
@@ -355,14 +335,14 @@ class VizResults:
         ]
 
         custom_data_columns_Bayesian = [
-            "Bayesian_D_max",
-            "Bayesian_D_max_std",
-            "Bayesian_significance",
-            "Bayesian_q",
-            "Bayesian_q_std",
-            "Bayesian_phi",
-            "Bayesian_phi_std",
-            "Bayesian_rho_Ac",
+            "damage",
+            "damage_std",
+            "significance",
+            "q",
+            "q_std",
+            "phi",
+            "phi_std",
+            "rho_Ac",
         ]
 
         self.hovertemplate = (
@@ -372,12 +352,11 @@ class VizResults:
             "    Rank: %{customdata[_XXX_]} <br>"
             "    ID:   %{customdata[_XXX_]} <br><br>"
             "<b>MAP results</b>: <br>"
-            "    D max:         %{customdata[_XXX_]:6.2%} ± %{customdata[_XXX_]:.2%} <br>"
+            "    D:             %{customdata[_XXX_]:6.2%} ± %{customdata[_XXX_]:.2%} <br>"
             "    significance: %{customdata[_XXX_]:6.2f} <br>"
             "    q:            %{customdata[_XXX_]:6.2f}  ± %{customdata[_XXX_]:.2f} <br>"
             "    phi:            %{customdata[_XXX_]:.3s} ± %{customdata[_XXX_]:.3s} <br>"
-            "    corr. Ac:      %{customdata[_XXX_]:6.3f} <br>"
-            "    asymmetry:     %{customdata[_XXX_]:6.3f} <br><br>"
+            "    corr. Ac:      %{customdata[_XXX_]:6.3f} <br><br>"
             "<b>Counts</b>: <br>"
             "    N reads:      %{customdata[_XXX_]:6.3s} <br>"
             "    N alignments: %{customdata[_XXX_]:6.3s} <br>"
@@ -388,7 +367,7 @@ class VizResults:
 
         hovertemplate_Bayesian = (
             "<b>Fit results</b>: <br>"
-            "    D max:         %{customdata[_XXX_]:6.2%} ± %{customdata[_XXX_]:.2%} <br>"
+            "    D:             %{customdata[_XXX_]:6.2%} ± %{customdata[_XXX_]:.2%} <br>"
             "    significance: %{customdata[_XXX_]:6.2f} <br>"
             "    q:            %{customdata[_XXX_]:6.2f}  ± %{customdata[_XXX_]:.2f} <br>"
             "    phi:            %{customdata[_XXX_]:.3s} ± %{customdata[_XXX_]:.3s} <br>"
@@ -396,7 +375,7 @@ class VizResults:
         )
 
         if self.contains_forward_only:
-            index = self.custom_data_columns.index("D_max")
+            index = self.custom_data_columns.index("MAP_damage")
             self.custom_data_columns[index:index] = ["forward_only_str"]
 
             index = self.hovertemplate.find("<b>MAP results</b>: <br>")
@@ -408,7 +387,7 @@ class VizResults:
 
         # if Bayesian fits, include these results
         if self.Bayesian:
-            index = self.custom_data_columns.index("D_max")
+            index = self.custom_data_columns.index("MAP_damage")
             self.custom_data_columns[index:index] = custom_data_columns_Bayesian
 
             index = self.hovertemplate.find("<b>MAP results</b>: <br>")
@@ -449,49 +428,33 @@ class VizResults:
         except Exception as e:
             raise e
 
-    def get_single_count_group(self, sample, tax_id, forward_reverse=""):
+    def get_single_count_group(self, sample, tax_id, forward_only=False):
         query = f"sample == '{sample}' & tax_id == '{tax_id}'"
         group_wide = self.df.query(query)
         group = wide_to_long_df(group_wide).dropna(axis="rows")
 
-        if forward_reverse.lower() == "forward":
+        if forward_only:
             return group.query(f"direction=='Forward'")
-        elif forward_reverse.lower() == "reverse":
-            return group.query(f"direction=='Reverse'")
         else:
             return group
 
-    def get_single_fit_prediction(self, sample, tax_id, forward_reverse=""):
+    def get_single_fit_prediction(self, sample, tax_id, forward_only=False):
         query = f"sample == '{sample}' & tax_id == '{tax_id}'"
         ds = self.df.query(query)
         if len(ds) != 1:
             raise AssertionError(f"Something wrong here, got: {ds}")
 
-        group = self.get_single_count_group(sample, tax_id, forward_reverse)
+        group = self.get_single_count_group(sample, tax_id, forward_only)
 
         if len(group) == 0:
-            if ds.iloc[0]["forward_only"] and forward_reverse.lower() == "reverse":
-                return "FORWARD ONLY"
-            else:
-                raise AssertionError(
-                    f"Something wrong here, got: {group=}, {tax_id=}, {forward_reverse=}"
-                )
+            raise AssertionError(
+                f"Something wrong here, got: {group=}, {tax_id=}, {forward_only=}"
+            )
 
-        # if self.contains_forward_only:
-        #     if forward_reverse.lower() == "reverse":
-        #         return "FORWARD ONLY"
-        #     else:
-        #         forward_reverse = ""
-
-        if forward_reverse.lower() == "forward":
-            prefix = "forward_"
-        elif forward_reverse.lower() == "reverse":
-            prefix = "reverse_"
+        if self.Bayesian:
+            prefix = ""
         else:
-            if self.Bayesian:
-                prefix = "Bayesian_"
-            else:
-                prefix = ""
+            prefix = "MAP_"
 
         A = getattr(ds, f"{prefix}A").values
         q = getattr(ds, f"{prefix}q").values
@@ -522,7 +485,7 @@ class VizResults:
 
         return d_out
 
-    def get_D_max(self, sample, tax_id):
+    def get_D(self, sample, tax_id):
         query = f"sample == '{sample}' & tax_id == '{tax_id}'"
         ds = self.df.query(query)
 
@@ -534,23 +497,19 @@ class VizResults:
             raise AssertionError(s)
 
         if self.Bayesian:
-            prefix = "Bayesian_"
-        else:
             prefix = ""
-
-        D_max = ds[f"{prefix}D_max"].iloc[0]
-
-        s1 = "Bayesian_D_max_confidence_interval_1_sigma_low"
-        s2 = "Bayesian_D_max_confidence_interval_1_sigma_high"
-        if s1 in ds and s2 in ds:
-            D_max_low = ds[s1].iloc[0]
-            D_max_high = ds[s2].iloc[0]
         else:
-            std = ds[f"{prefix}D_max_std"].iloc[0]
-            D_max_low = D_max - std
-            D_max_high = D_max + std
+            prefix = "MAP_"
 
-        return D_max, D_max_low, D_max_high
+        D = ds[f"{prefix}damage"].iloc[0]
+        D_sigma = ds[f"{prefix}damage_std"].iloc[0]
+
+        # s1 = f"{prefix}damage_CI_low"
+        # s2 = f"{prefix}damage_CI_high"
+        # D_low = ds[s1].iloc[0]
+        # D_high = ds[s2].iloc[0]
+
+        return D, D_sigma
 
     def _ds_to_fit_text(self, ds):
 
@@ -566,29 +525,27 @@ class VizResults:
         text = r"$\mathrm{Bayesian}" if self.Bayesian else r"$\mathrm{MAP}"
         text += r"\,\, \mathrm{fit}$" + "\n\n"
 
-        D_max_col = "Bayesian_D_max" if self.Bayesian else "D_max"
-        D_max_str = sanitize(D_max_col)
-        D_max = ds[D_max_col].iloc[0]
-        D_max_std = ds[D_max_col + "_std"].iloc[0]
-        text += (
-            "$" + D_max_str + f" = {D_max:.3f} " + r"\pm" + f" {D_max_std:.3f}" + r"$"
-        )
+        D_col = "damage" if self.Bayesian else "MAP_damage"
+        D_str = sanitize(D_col)
+        D = ds[D_col].iloc[0]
+        D_std = ds[D_col + "_std"].iloc[0]
+        text += "$" + D_str + f" = {D:.3f} " + r"\pm" + f" {D_std:.3f}" + r"$"
         text += "\n"
 
-        fitqual_col = "Bayesian_significance" if self.Bayesian else "significance"
+        fitqual_col = "significance" if self.Bayesian else "MAP_significance"
         fitqual_str = sanitize(fitqual_col)
         fitqual = ds[fitqual_col].iloc[0]
         text += "$" + fitqual_str + f" = {fitqual:.2f} " + r"$"
         text += "\n"
 
-        phi_col = "Bayesian_phi" if self.Bayesian else "phi"
+        phi_col = "phi" if self.Bayesian else "MAP_phi"
         phi_str = sanitize(phi_col)
         phi = viz_utils.human_format(ds[phi_col].iloc[0])
         phi_std = viz_utils.human_format(ds[phi_col + "_std"].iloc[0])
         text += "$" + phi_str + f" = {phi} " + r"\pm" + f" {phi_std}" + r"$"
         text += "\n"
 
-        q_col = "Bayesian_q" if self.Bayesian else "q"
+        q_col = "q" if self.Bayesian else "MAP_q"
         q_str = sanitize(q_col)
         q = ds[q_col].iloc[0]
         q_std = ds[q_col + "_std"].iloc[0]
